//
// PS2PC: An Intel x86 emulator for MIPS R5900 (Sony PS2).
// Coded by Mike Tedder / breakpoint - bpoint@parodius.com
// http://ps2pc.parodius.com
//
// This project is released as 'open source'.  You may make any modifications
// or adjustments to the code and submit a patch to be applied to the project.
// See the web page for more details.
//
//-----------------------------------------------------------------------

#include "config.h"
#include "types.h"
#include "cpu.h"
#include "dynrec.h"
#include "debug.h"
#include "mem.h"
#include "r59basic.h"


cpuState gCpu;

void cpuReset(void)
{
	gCpu.eflags = 0x00000002;
	gCpu.eip    = 0x0000FFF0;
	gCpu.cs     = 0xF000;
	gCpu.ds     = 0x0000;
	gCpu.es     = 0x0000;
	gCpu.fs     = 0x0000;
	gCpu.gs     = 0x0000;

	gCpu.idtr_base  = 0x00000000;
	gCpu.idtr_limit = 0x03FF;

	gCpu.dr6 = 0xFFFF0FF0;
	gCpu.dr7 = 0x00000000;
}

bool cpuExec(void)
{
	int xlated, size;
	uchar *pcAddr;
#if (PS2_VERSION)
	void *pCpu;
	ulong pBuf;
#endif

	// hack for now -- just use lower 16 bits of EIP to get address...
	pcAddr = (uchar *)memCalcSegOfsAddr(gCpu.cs, (ushort)gCpu.eip);

// TODO: see if pc address is in cached space... if so, use pre-compiled code.
//	if (...)
	{
		// compile code to global buffer...
		xlated = dynrecCompileBlock(pcAddr, (ulong *)gdrCompileBuffer, &size);
#if (DO_DEBUG)
		// bail if we hit a 'not done' opcode.
		if (xlated == -1) return FALSE;

		// check to make sure we didn't do any buffer overflows...
		if ((size + 4) > (CFG_DYNREC_COMPILE_BUF_SIZE * 1024))
		{
			debugPrintf("FATAL: compiled code exceeded buffer size!\n");
			debugPrintf("FATAL: increase CFG_DYNREC_COMPILE_BUF_SIZE and rebuild.\n");
			return FALSE;
		}
#endif

// TODO: allocate space in cache buffer, and copy up the compiled code.
	}

	// encode 'jr ra' to end of code...
	*( ((ulong *)gdrCompileBuffer) + (size >> 2) ) = r5900JR(rRA);

#if (PS2_VERSION)
	// run asm code to load x86 cpu registers to ps2 regs, execute code, then restore registers...
	pCpu = (void *)&gCpu;
	pBuf = (ulong )gdrCompileBuffer;
	asm __volatile__ ("
		lw $8, 0(%0)
		lw $9, 4(%0)
		lw $10, 8(%0)
		lw $11, 12(%0)
		lw $12, 16(%0)
		lw $13, 20(%0)
		lw $14, 24(%0)
		lw $15, 28(%0)
		lw $24, 32(%0)
		lw $25, 36(%0)
		lw $18, 40(%0)
		lw $19, 44(%0)
		lw $20, 48(%0)
		lw $21, 52(%0)
		lw $22, 56(%0)
		jal %1
		nop
		sw $8, 0(%0)
		sw $9, 4(%0)
		sw $10, 8(%0)
		sw $11, 12(%0)
		sw $12, 16(%0)
		sw $13, 20(%0)
		sw $14, 24(%0)
		sw $15, 28(%0)
		sw $24, 32(%0)
		sw $25, 36(%0)
		sw $18, 40(%0)
		sw $19, 44(%0)
		sw $20, 48(%0)
		sw $21, 52(%0)
		sw $22, 56(%0)
		"
		:
		: "r" (pCpu), "r" (pBuf)
	);
#endif

	return TRUE;
}
