//
// PS2PC: An Intel x86 emulator for MIPS R5900 (Sony PS2).
// Coded by Mike Tedder / breakpoint - bpoint@parodius.com
// http://ps2pc.parodius.com
//
// This project is released as 'open source'.  You may make any modifications
// or adjustments to the code and submit a patch to be applied to the project.
// See the web page for more details.
//
//-----------------------------------------------------------------------

#ifndef CPU_H
#define CPU_H

#include "types.h"


typedef struct
{
	// registers and flags (kept in ps2 regs at runtime) -- do NOT change the order of any elements in this structure!
	ulong  eax;			// rT0
	ulong  ebx;			// rT1
	ulong  ecx;			// rT2
	ulong  edx;			// rT3
	ulong  esi;			// rT4
	ulong  edi;			// rT5
	ulong  ebp;			// rT6
	ulong  esp;			// rT7
	ulong  eip;			// rT8
	ulong  eflags;		// rT9
	ushort cs;			// rS2
	ushort ds;			// rS3
	ushort es;			// rS4
	ushort fs;			// rS5
	ushort gs;			// rS6

	// extended registers (always accessed to/from ps2 memory)
	ulong  idtr_base;
	ushort idtr_limit;
	ulong  dr6;
	ulong  dr7;
} cpuState;

extern cpuState gCpu;


void cpuReset(void);
bool cpuExec(void);

#endif
