//
// PS2PC: An Intel x86 emulator for MIPS R5900 (Sony PS2).
// Coded by Mike Tedder / breakpoint - bpoint@parodius.com
// http://ps2pc.parodius.com
//
// This project is released as 'open source'.  You may make any modifications
// or adjustments to the code and submit a patch to be applied to the project.
// See the web page for more details.
//
//-----------------------------------------------------------------------

#include "config.h"
#include "types.h"
#include "devices.h"
#include "Devices/devdefs.h"
#include "Devices/oak.h"

// List of device definition blocks...
devDeviceDefinition oakDeviceBlock;

// List of devices that will be registered on startup...
struct
{
	void (*devRegisterDefinitionFunc)(devDeviceDefinition *devDef);
	devDeviceDefinition *devBlk;
} devDeviceList[] = {
	{ oakRegisterDevice, &oakDeviceBlock },
	{ NULL,              NULL            },
};


void devInit(void)
{
	int t = 0;

	while (devDeviceList[t].devRegisterDefinitionFunc != NULL)
	{
		devDeviceList[t].devRegisterDefinitionFunc(devDeviceList[t].devBlk);
		t++;
	}
}


void devScanDevices(void (*callbackFunc)(int devIdx, devDeviceDefinition *devBlk))
{
	int t = 0;

	while (devDeviceList[t].devRegisterDefinitionFunc != NULL)
	{
		callbackFunc(t, devDeviceList[t].devBlk);
		t++;
	}
}


bool devInitDevice(int devIdx)
{
	if (devDeviceList[devIdx].devBlk->devInitFunc(devDeviceList[devIdx].devBlk) == FALSE)
	{
		// device initialization failed!
		return FALSE;
	}

	return TRUE;
}


bool devRequestPorts(devDeviceDefinition *devBlk)
{
	// we'll take the devBlk read/write IO functions and add them to an I/O table here later...
	return TRUE;
}


bool devRequestMemory(devDeviceDefinition *devBlk)
{
	// more stuff here later...
	return TRUE;
}
