//
// PS2PC: An Intel x86 emulator for MIPS R5900 (Sony PS2).
// Coded by Mike Tedder / breakpoint - bpoint@parodius.com
// http://ps2pc.parodius.com
//
// This project is released as 'open source'.  You may make any modifications
// or adjustments to the code and submit a patch to be applied to the project.
// See the web page for more details.
//
//-----------------------------------------------------------------------

#include "config.h"
#include "types.h"
#include "x86.h"
#include "x86jmp.h"
#include "r59basic.h"


//=====================
//        JMP
//=====================

int x86JMP_Jv(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JMP_Ap(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	ushort cs, ip;
	ulong eip;

	*isBranch = TRUE;

	if (gIn32BitMode)
	{
		// read cs:eip..
		eip = MAKE_DWORD(*(in + 4), *(in + 3), *(in + 2), *(in + 1));
		cs  = MAKE_WORD (*(in + 6), *(in + 5));

		*(out    ) = r5900ORI(rS2, rR0, cs);
		*(out + 1) = r5900LUI(rT8, HI_WORD(eip));
		*(out + 2) = r5900ORI(rT8, rT8, LO_WORD(eip));

		*skip += 3;
		return 7;
	}
	else
	{
		// read cs:ip..
		ip = MAKE_WORD(*(in + 2), *(in + 1));
		cs = MAKE_WORD(*(in + 4), *(in + 3));

		*(out    ) = r5900ORI(rS2, rR0, cs);
		*(out + 1) = r5900ORI(rT8, rR0, ip);

		*skip += 2;
		return 5;
	}
}


int x86JMP_Jb(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}



//=====================
//  Conditional Jump
//=====================

int x86JO(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JNO(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JB(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JNB(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JZ(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JNZ(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JBE(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JNBE(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JS(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JNS(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JP(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JNP(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JL(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JNL(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JLE(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JNLE(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86JCXZ_Jb(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}



//=====================
//  LOOP/LOOPE/LOOPNE
//=====================

int x86LOOP_Jb(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86LOOPE_Jb(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86LOOPNE_Jb(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}



//=====================
//   CALL/RET/IRET
//=====================

int x86CALL_Ap(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86CALL_Jv(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86RET_Iw(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86RET(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86RETF_Iw(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86RETF(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86IRET(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}



//=====================
//    INT3/INT/INTO
//=====================

int x86INT_3(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86INT_Ib(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


int x86INTO(uchar *in, ulong *out, bool *isBranch, ulong *skip)
{
	return 0;
}


