//
// PS2PC: An Intel x86 emulator for MIPS R5900 (Sony PS2).
// Coded by Mike Tedder / breakpoint - bpoint@parodius.com
// http://ps2pc.parodius.com
//
// This project is released as 'open source'.  You may make any modifications
// or adjustments to the code and submit a patch to be applied to the project.
// See the web page for more details.
//
//-----------------------------------------------------------------------

#ifndef X86MISC_H
#define X86MISC_H

#include "types.h"

int x86CMP_EbGb(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86CMP_EvGv(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86CMP_GbEb(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86CMP_GvEv(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86CMP_ALIb(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86CMP_eAXIv(uchar *in, ulong *out, bool *isBranch, ulong *skip);

int x86TEST_EbGb(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86TEST_EvGv(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86TEST_ALIb(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86TEST_eAXIv(uchar *in, ulong *out, bool *isBranch, ulong *skip);

int x86XCHG_EbGb(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86XCHG_EvGv(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86XCHG_eAXeCX(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86XCHG_eAXeDX(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86XCHG_eAXeBX(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86XCHG_eAXeSP(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86XCHG_eAXeBP(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86XCHG_eAXeSI(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86XCHG_eAXeDI(uchar *in, ulong *out, bool *isBranch, ulong *skip);

int x86MOVSB_XbYb(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86MOVSWD_XvYv(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86CMPSB_XbYb(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86CMPSWD_XvYv(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86STOSB_YbAL(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86STOSWD_YveAX(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86LODSB_ALXb(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86LODSWD_eAXXv(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86SCASB_ALYb(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86SCASWD_eAXYv(uchar *in, ulong *out, bool *isBranch, ulong *skip);

int x86LEA_GvM(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86LDS_GvMp(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86LES_GvMp(uchar *in, ulong *out, bool *isBranch, ulong *skip);

int x86REP(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86REPNE(uchar *in, ulong *out, bool *isBranch, ulong *skip);

int x86NOP(uchar *in, ulong *out, bool *isBranch, ulong *skip);

int x86Seg_CS(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86Seg_DS(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86Seg_ES(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86Seg_SS(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86Seg_FS(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86Seg_GS(uchar *in, ulong *out, bool *isBranch, ulong *skip);

int x86AAA(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86AAD(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86AAM(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86AAS(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86DAA(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86DAS(uchar *in, ulong *out, bool *isBranch, ulong *skip);

int x86CMC(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86CLC(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86STC(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86CLI(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86STI(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86CLD(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86STD(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86SAHF(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86LAHF(uchar *in, ulong *out, bool *isBranch, ulong *skip);

int x86BOUND_GvMa(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86CBW(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86CWD(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86SALC(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86XLAT(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86LOCK(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86HLT(uchar *in, ulong *out, bool *isBranch, ulong *skip);
int x86WAIT(uchar *in, ulong *out, bool *isBranch, ulong *skip);

#endif
